/*******************************************************************************
Sam Langfield and Marco Pagano (2015)
"Bank bias in Europe: Effects on Systemic Risk and Growth"
Economic Policy
*******************************************************************************/

/*******************************************************************************
Growth regressions
*******************************************************************************/

/*******************************************************************************
HOUSEKEEPING
*******************************************************************************/

version 13.0

*Set your working directory here:
cd "C:\Users\SPL\Dropbox\Research\Pagano-Langfield_EP_Bank-bias\Data\CLEAN"

clear all
cap log close
set more off
set scheme s1color

import excel B_LongBankTA.xlsx, sheet("MASTER") firstrow clear

/*******************************************************************************
GENERATE AND RENAME VARIABLES
*******************************************************************************/

drop ta_*
drop S T

encode co, gen(cocode)

gen wealth_ngdp = wealth / ngdp

gen countrycode=""
replace countrycode = "AUS" if co=="AU"
replace countrycode = "BEL" if co=="BE"
replace countrycode = "CHE" if co=="CH"
replace countrycode = "CAN" if co=="CN"
replace countrycode = "DEU" if co=="DE"
replace countrycode = "DNK" if co=="DK"
replace countrycode = "ESP" if co=="ES"
replace countrycode = "FRA" if co=="FR"
replace countrycode = "ITA" if co=="IT"
replace countrycode = "JPN" if co=="JP"
replace countrycode = "NLD" if co=="NL"
replace countrycode = "NOR" if co=="NO"
replace countrycode = "GBR" if co=="UK"
replace countrycode = "USA" if co=="US"

gen d_eu=0
replace d_eu=1 if (co=="BE" | co=="DK" | co=="IT" | co=="NL" | co=="ES" | co=="UK" | co=="DE" | co=="FR")

/************************************
CONVERT US SERIES TO IFRS EQUIVALENT
************************************/

*For reference, see "R_GAAP-IFRS derivs off-balance sheet adjustment.xlsx"
gen ta_original = ta
format ta_original %14.2fc
replace ta = ta + 4635220 if (co=="US" & year==2013)
replace ta = ta + 5895301 if (co=="US" & year==2012)
replace ta = ta + 6819913.6833 if (co=="US" & year==2011)
replace ta = ta + 5306805.316 if (co=="US" & year==2010)
replace ta = ta + 5427319.919 if (co=="US" & year==2009)
replace ta = ta + 4994852.29443491 if (co=="US" & year==2008)
replace ta = ta + 4674998.79133379 if (co=="US" & year==2007)
replace ta = ta + 3464957.22954184 if (co=="US" & year==2006)
replace ta = ta + 2543771.54781397 if (co=="US" & year==2005)
replace ta = ta + 2289022.02843796 if (co=="US" & year==2004)
replace ta = ta + 1738427.37593425 if (co=="US" & year==2003)
replace ta = ta + 1249955.12536386 if (co=="US" & year==2002)
replace ta = ta + 982246.83818474 if (co=="US" & year==2001)
replace ta = ta + 839576.238484675 if (co=="US" & year==2000)
replace ta = ta + 778525.200991634 if (co=="US" & year==1999)

gen ta_ngdp = ta / ngdp
gen ta_wealth = ta / wealth
gen ta_stock = ta / stock

/************************************
ENSURE THAT STOCK DATA USES WORLD BANK SERIES WHERE AVAILABLE
************************************/

replace bond_gdp_WB = bond_gdp_WB/100
replace stock_gdp_WB = stock_gdp_WB/100

gen bond_gdp = bond_gdp_WB
replace bond_gdp = bond_gdp_Zingales if missing(bond_gdp_WB)

replace stock_gdp = stock_gdp_WB if stock_gdp_WB<999999999

gen ta_stockbond = ta_ngdp / (stock_gdp + bond_gdp)

/************************************
TIDY
************************************/

drop stock 
drop wealth

/************************************
SAVING
************************************/

save X2_LongTA_prepped, replace
*outsheet using "X2_LongTA_prepped.csv", comma replace

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************


/************************************
FIGURE 1: Total bank assets to GDP in Europe, the US and Japan
************************************/

use X2_LongTA_prepped, clear
sort year source_ta

drop if missing(ta_ngdp)

drop if (co=="FR") //exclude FR (too short)

drop if source_ta==0 //exclude S&T obs
drop if (source_ta==26 | source_ta==27) //exclude CBD obs

drop if (co=="DK" & source_ta==10 & year>1999)
drop if (co=="NL" & source_ta==5)
drop if (co=="ES" & source_ta==16 & year>1982)
drop if (co=="ES" & source_ta==5)
drop if (co=="DE" & source_ta==5)
drop if (co=="IT" & source_ta==5)

keep if (d_eu==1 | co=="JP" | co=="US")

bys year d_eu: egen med_ta_ngdp = median(ta_ngdp)
replace med_ta_ngdp = . if d_eu==0
replace med_ta_ngdp = . if year==1945

graph twoway ///
	scatter med_ta_ngdp year if (d_eu==1), msymbol(O) lwidth(med) lpattern("--") msize(medsmall) c(l) cmiss(y) sort(year) lcolor(gs0) mcolor(gs0)  || ///
	scatter ta_ngdp year if (co=="US"), msymbol(X) lwidth(med) lpattern(".") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs6) mcolor(gs6) || ///
	scatter ta_ngdp year if (co=="JP"), msymbol(D) lwidth(med) lpattern("#") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs10) mcolor(gs10) ///
		legend(rows(1) region(lcolor(white)) label(1 "Europe") label(2 "US") label(3 "Japan")) ///
		ytitle("Total bank assets to GDP") xtitle("") ylabel(0 "0" 2 "2" 4) xlabel(1880 "1880" 1920 1960 2000 "2000") xsize(13) ysize(10) scale(1.25) name("EU7_median", replace)
		
graph export Z_Fig1_ta_gdp.emf, replace

/************************************
Figure 3: Total bank assets to private wealth in Germany, the UK and the US
************************************/

use X2_LongTA_prepped, clear

drop if source_ta==0

keep if (co=="DE" | co=="US" | co=="UK")

drop if (co=="DE" & source_ta==5)
drop if (co=="DE" & source_ta==26)
drop if (co=="DE" & source_ta==27)

drop if (co=="UK" & source_ta==26)
drop if (co=="UK" & source_ta==27)


graph twoway  ///
	scatter ta_wealth year if co=="DE", msymbol(D) lwidth(medsmall) lpattern(".") msize(small) c(l) cmiss(y) sort(year) lcolor(gs0) mcolor(gs0) || ///
	scatter ta_wealth year if co=="UK", msymbol(T) lwidth(medlarge) lpattern("--") msize(small) c(l) cmiss(y) sort(year) lcolor(gs6) mcolor(gs6) || ///
	scatter ta_wealth year if co=="US", msymbol(X) lwidth(med) lpattern(".") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs8) mcolor(gs8) ///
		legend(rows(1) label(3 "US") label(1 "Germany") label(2 "UK") region(lcolor(white)) ) ///
		xtitle("") ylabel(0 0.5 "0.5" 1) ///
		xlabel(1880 "1880" 1920 1960 2000 "2000") xsize(13) ysize(10) scale(1.25) ///
		ytitle("Total bank assets to private wealth") name("wealth_longts", replace)
		

graph export Z_Fig3_ta_wealth.emf, replace


/*
/************************************
Short time series alternative to Figure 3 (not shown in paper)
************************************/

use X2_LongTA_prepped, clear

drop if source_ta==0

drop if (co=="DE" | co=="US" | co=="UK")
drop if (co=="BE" | co=="DK" | co=="CH" | co=="NO" | co=="NL")

drop if missing(ta_wealth)

drop if (source_ta==26 | source_ta==27)
drop if (source_ta==11)
drop if (source_ta==5 & co=="ES")
drop if (source_ta==16 & co=="ES")

*IT ES FR
graph twoway  ///
	scatter ta_wealth year if co=="IT", c(l) cmiss(y) lcolor(red) lwidth(med) lpattern("--") msymbol(O) mcolor(red) msize(small) || ///
	scatter ta_wealth year if co=="ES", c(l) cmiss(y) lcolor(gs0) lwidth(med) lpattern("--") msymbol(O) mcolor(gs0) msize(small) || ///
	scatter ta_wealth year if co=="FR", c(l) cmiss(y) lcolor(blue) lwidth(med) lpattern("--") msymbol(O) mcolor(blue) msize(small) ///
		legend(rows(1) label(1 "IT") label(2 "ES") label(3 "FR") region(lcolor(white)) ) ///
		title("Bank total assets / Private wealth") ytitle("") xtitle("") ylabel(0 0.5 "0.5" 1 1.4 " ") ///
		xlabel(1880 "1880" 1920 1960 2000 "2000") xsize(12) ysize(10) scale(1.25) ///
		name("wealth_shortts_ITESFR", replace)

*AU CN JP
graph twoway  ///
	scatter ta_wealth year if co=="AU", c(l) cmiss(y) lcolor(red) lwidth(med) lpattern("--") msymbol(O) mcolor(red) msize(small) || ///
	scatter ta_wealth year if co=="CN", c(l) cmiss(y) lcolor(gs0) lwidth(med) lpattern("--") msymbol(O) mcolor(gs0) msize(small) || ///
	scatter ta_wealth year if co=="JP", c(l) cmiss(y) lcolor(blue) lwidth(med) lpattern("--") msymbol(O) mcolor(blue) msize(small) ///
		legend(rows(1) label(1 "AU") label(2 "CN") label(3 "JP") region(lcolor(white)) ) ///
		title("Bank total assets / Private wealth") ytitle("") xtitle("") ylabel(0 0.5 "0.5" 1 1.4 " ") ///
		xlabel(1880 "1880" 1920 1960 2000 "2000") xsize(12) ysize(10) scale(1.25) ///
		name("wealth_shortts_AUCNJP", replace)
*/


/************************************
FIGURE 2: TA/GDP COUNTRY charts
************************************/

use X2_LongTA_prepped, clear

drop if missing(ta_ngdp)

		*EU

graph twoway ///
	scatter ta_ngdp year if (co=="BE" & source_ta==5), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="BE" & source_ta==6), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///	
		graphregion(margin(medsmall)) ///
		title("Belgium", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("BE", replace) ysize(4.9) xsize(6.25)

graph export ZZ01_BE.emf, replace

		
graph twoway ///
	scatter ta_ngdp year if (co=="DK" & source_ta==5), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="DK" & source_ta==10 & year<2000), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year)  ///
		legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///
		graphregion(margin(medsmall)) ///		
		title("Denmark", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("DK", replace) ysize(4.9) xsize(6.25)

graph export ZZ02_DK.emf, replace

		
graph twoway ///
	scatter ta_ngdp year if (co=="DE" & source_ta==5), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="DE" & source_ta==24 & year<1997), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="DE" & source_ta==25), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///		
				graphregion(margin(medsmall)) ///
		title("Germany", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("DE", replace) ysize(4.9) xsize(6.25)

graph export ZZ03_DE.emf, replace


drop if (source_ta==16 & year>1982) //delete strange obs from 1983-2000 from source_ta==16	
graph twoway ///
	scatter ta_ngdp year if (co=="ES" & source_ta==16), c(l) cmiss(y) lcolor(gs10) lwidth(med) lpattern(".") msymbol(O) mcolor(gs10) msize(small) || ///
	scatter ta_ngdp year if (co=="ES" & source_ta==17), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "sources:" 2 "central bank" 1 "EHRG") region(lcolor(white)))  ///
				graphregion(margin(medsmall)) ///
		title("Spain", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("ES", replace) ysize(4.9) xsize(6.25)

graph export ZZ07_ES.emf, replace

		
graph twoway ///
	scatter ta_ngdp year if (co=="FR" & source_ta==5), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="FR" & source_ta==5), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
	legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///	
			graphregion(margin(medsmall)) ///
		title("France", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("FR", replace) ysize(4.9) xsize(6.25)

graph export ZZ04_FR.emf, replace

		
graph twoway ///
	scatter ta_ngdp year if (co=="IT" & source_ta==11), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="IT" & source_ta==11), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
	legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///		
			graphregion(margin(medsmall)) ///
		title("Italy", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("IT", replace) ysize(4.9) xsize(6.25)

graph export ZZ05_IT.emf, replace


graph twoway ///
	scatter ta_ngdp year if (co=="NL" & source_ta==5), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="NL" & source_ta==14 & year<1996 & year!=1945 & year!=1944), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///
				graphregion(margin(medsmall)) ///
		title("Netherlands", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("NL", replace) ysize(4.9) xsize(6.25)

graph export ZZ06_NL.emf, replace

		
graph twoway ///
	scatter ta_ngdp year if (co=="UK" & source_ta==20), c(l) cmiss(y) lcolor(gs10) lwidth(med) lpattern(".") msymbol(O) mcolor(gs10) msize(small) || ///
	scatter ta_ngdp year if (co=="UK" & source_ta==19), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "sources:" 2 "central bank" 1 "Sheppard") region(lcolor(white)))  ///
				graphregion(margin(medsmall)) ///
		title("United Kingdom", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("UK", replace) ysize(4.9) xsize(6.25)
		
graph export ZZ08_UK.emf, replace


		*non-Europe

graph twoway ///
	scatter ta_ngdp year if (co=="AU" & source_ta==1), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="AU" & source_ta==2), c(l) cmiss(y) lcolor(gs10) lwidth(med) lpattern(".") msymbol(O) mcolor(gs10) msize(small) || ///
	scatter ta_ngdp year if (co=="AU" & source_ta==4), lcolor(gs6) mcolor(gs6) lpattern("--") msymbol(Oh) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="AU" & source_ta==3), lcolor(gs6) mcolor(gs6) lpattern("--") msymbol(Oh) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///	
		legend(rows(1) order(- "sources:" 1 "CB" 3 "gvt" 2 "Drummond") region(lcolor(white)))  ///	
				graphregion(margin(medsmall)) ///
		title("Australia", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("AU", replace) ysize(4.9) xsize(6.25)

graph export ZY01_AU.emf, replace


graph twoway ///
	scatter ta_ngdp year if (co=="CN" & source_ta==8), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="CN" & source_ta==7), lcolor(gs6) mcolor(gs6) lpattern("--") msymbol(Oh) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="CN" & source_ta==9), c(l) cmiss(y) lcolor(gs10) lwidth(med) lpattern(".") msymbol(O) mcolor(gs10) msize(small) || ///
	scatter ta_ngdp year if (co=="CN" & source_ta==28), lcolor(gs6) mcolor(gs6) lpattern("--") msymbol(Oh) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
	legend(rows(1) order(- "sources:" 1 "CB" 2 "OSFI" 3 "Drummond") region(lcolor(white)))  ///	
			graphregion(margin(medsmall)) ///
		title("Canada", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("CN", replace) ysize(4.9) xsize(6.25)
		
graph export ZY02_CN.emf, replace	


graph twoway ///
	scatter ta_ngdp year if (co=="JP" & source_ta==13), lcolor(gs6) mcolor(gs6) lpattern("--") msymbol(Oh) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="JP" & source_ta==12), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "sources:" 1 "central bank" 2 "Statistics Japan") region(lcolor(white)))  ///		
				graphregion(margin(medsmall)) ///
		title("Japan", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("JP", replace) ysize(4.9) xsize(6.25)

graph export ZY03_JP.emf, replace


graph twoway ///
	scatter ta_ngdp year if (co=="US" & source_ta==22 & year<1900), lcolor(gs12) mcolor(gs12) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="US" & source_ta==22 & year>1900), lcolor(gs12) mcolor(gs12) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="US" & source_ta==23), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="US" & source_ta==29), lcolor(gs6) mcolor(gs6) lpattern("--") msymbol(Oh) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="US" & source_ta==21), lcolor(gs6) mcolor(gs6) lpattern("--") msymbol(Oh) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "sources: " 3 "Fed" 1 "USCB" 4 "FDIC") region(lcolor(white)))  ///	
				graphregion(margin(medsmall)) ///
		title("United States", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("US", replace) ysize(4.9) xsize(6.25)

graph export ZY04_US.emf, replace


*Europe non-EU

graph twoway ///
	scatter ta_ngdp year if (co=="NO" & source_ta==15), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="NO" & source_ta==14), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///		
				graphregion(margin(medsmall)) ///
		title("Norway", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("NO", replace) ysize(4.9) xsize(6.25)

graph export ZX01_NO.emf, replace
		
graph twoway ///
	scatter ta_ngdp year if (co=="CH" & source_ta==18), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) || ///
	scatter ta_ngdp year if (co=="CH" & source_ta==19), lcolor(gs0) mcolor(gs0) lpattern("--") msymbol(O) msize(small) lwidth(med) c(l) cmiss(y) sort(year) ///
		legend(rows(1) order(- "source:" 1 "central bank") region(lcolor(white)))  ///
				graphregion(margin(medsmall)) ///
		title("Switzerland", size(medlarge)) ytitle("") xtitle("") ylabel(0 (2) 6) xlabel(1880 "1880" 1920 1960 2000 "2000") scale(1.4) name("CH", replace) ysize(4.9) xsize(6.25)

graph export ZX02_CH.emf, replace


/************************************
Figure 4: Bank-market ratio since 1900 in Germany, the UK and the US
************************************/

use X2_LongTA_prepped, clear

drop if (co=="FR") //exclude FR (too short)
drop if source_ta==0 //exclude S&T obs
drop if (source_ta==26 | source_ta==27) //exclude CBD obs
drop if (co=="DK" & source_ta==10 & year>1999)
drop if (co=="NL" & source_ta==5)
drop if (co=="ES" & source_ta==16 & year>1982)
drop if (co=="ES" & source_ta==5)
drop if (co=="DE" & source_ta==5)
drop if (co=="IT" & source_ta==5)

keep if (d_eu==1 | co=="JP" | co=="US")
drop if missing(ta_stockbond)

******

xtset cocode year

bys year d_eu: egen med_ta_stockbond = median(ta_stockbond)
replace med_ta_stockbond = . if d_eu==0
replace med_ta_stockbond = . if year==1950

******

keep if (year<1991 | year==1996 | year==2001 | year==2006 | year==2011)

keep if (co=="DE" | co=="UK" | co=="US")
keep ta_stockbond countrycode year ta_ngdp stock_gdp bond_gdp
sort year countrycode
order year countrycode ta_stockbond ta_ngdp stock_gdp bond_gdp
edit
kkk
clear all
edit
kkk
		
graph twoway ///
	scatter ta_stockbond year if co=="DE", msymbol(D) lwidth(medsmall) lpattern(".") msize(small) c(l) cmiss(y) sort(year) lcolor(gs0) mcolor(gs0) || ///
	scatter ta_stockbond year if co=="UK", msymbol(T) lwidth(medlarge) lpattern("--") msize(small) c(l) cmiss(y) sort(year) lcolor(gs6) mcolor(gs6) || ///
	scatter ta_stockbond year if co=="US", msymbol(X) lwidth(med) lpattern(".") msize(vsmall) c(l) cmiss(y) sort(year) lcolor(gs8) mcolor(gs8) ///
		legend(rows(1) region(lcolor(white)) label(1 "Germany") label(2 "UK") label(3 "US")) ///
		ytitle("Bank-market ratio") xtitle("") ylabel(0(1)7) xlabel(1880 "1880" 1920 1960 2000 "2000") xsize(13) ysize(10) scale(1.25) name("Str_EU8_median", replace)

graph export Z_Fig4_structure_STOCKBOND.emf, replace
